==> maDB_1.4.0.tar.gz: maDB/man/checkForAnnotation.Rd <==
\name{checkForDifferentAnnotation}
\alias{checkForDifferentAnnotation}
\title{Detect gene annotation differences}
\description{
  \code{checkForDifferentAnnotation} compares the gene annotation in the \code{annotation} database table with the gene annotation provided by the specified R annotation package. The IDs which differ in the annotation are returned in a table.
}
\usage{
checkForDifferentAnnotation(con,chip,check.columns=c("GenBank","UniGene","LocusLink"),v=TRUE)
}
\arguments{
  \item{con}{The connection object to the database (Connections can be opened with the \code{\link{dbConnect}} function from the \pkg{RdbiPgSQL} package).}
  \item{chip}{The chip for which the annotation should be checked. At the moment only Affymetrix chips are supported (eg. \code{hgu133plus2}).}
  \item{check.columns}{The identifiers that should be compared for the genes (Affymetrix probe sets).}
  \item{v}{if some additional informations should be written to the console.}
}
\details{
This function compares the annotation for the genes (or Affymetrix probe set IDs) that are available in a database table called \code{annotation} and the corresponding R annotation package (like the \code{hgu133plus2} package). The annotation IDs specified by the \code{check.columns} attribute from the two different sources are compared for each gene and if they differ the gene and the different annotations are returned.
}
\references{}
\author{Johannes Rainer}

\seealso{
	\code{\link{dbConnect}}
	\code{\link{dbUpdateAnnotation}}
	\code{\link{dbGetAnnotation}}
	\code{\link{createDBTable}}
}

\examples{
}

\keyword{data}

==> maDB_1.6.0.tar.gz: maDB/man/checkForAnnotation.Rd <==
\name{checkForDifferentAnnotation}
\alias{checkForDifferentAnnotation}
\title{Detect gene annotation differences}
\description{
  \code{checkForDifferentAnnotation} compares the gene annotation in the \code{annotation} database table with the gene annotation provided by the specified R annotation package. The IDs which differ in the annotation are returned in a table.
}
\usage{
checkForDifferentAnnotation(con,chip,check.columns=c("GenBank","UniGene","LocusLink"),v=TRUE)
}
\arguments{
  \item{con}{The connection object to the database (Connections can be opened with the \code{dbConnect} function from the \pkg{RdbiPgSQL} package).}
  \item{chip}{The chip for which the annotation should be checked. At the moment only Affymetrix chips are supported (eg. \code{hgu133plus2}).}
  \item{check.columns}{The identifiers that should be compared for the genes (Affymetrix probe sets).}
  \item{v}{if some additional informations should be written to the console.}
}
\details{
This function compares the annotation for the genes (or Affymetrix probe set IDs) that are available in a database table called \code{annotation} and the corresponding R annotation package (like the \code{hgu133plus2} package). The annotation IDs specified by the \code{check.columns} attribute from the two different sources are compared for each gene and if they differ the gene and the different annotations are returned.
}
\references{}
\author{Johannes Rainer}

\seealso{
%	\code{\link{dbConnect}}
	\code{\link{dbUpdateAnnotation}}
	\code{\link{dbGetAnnotation}}
%	\code{\link{createDBTable}}
}

\examples{
}

\keyword{data}
